<template>
  <Dialog :title="dialogTitle" v-model="dialogVisible">
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="模型id" prop="modelId">
        <el-input v-model="formData.modelId" placeholder="请输入模型id" />
      </el-form-item>
      <el-form-item label="会话id" prop="conversationId">
        <el-input v-model="formData.conversationId" placeholder="请输入会话id" />
      </el-form-item>
      <el-form-item label="消息id" prop="messageId">
        <el-input v-model="formData.messageId" placeholder="请输入消息id" />
      </el-form-item>
      <el-form-item label="调度建议" prop="content">
        <Editor v-model="formData.content" height="150px" />
      </el-form-item>
      <el-form-item label="状态（0-未处理 1-已采纳 2-已忽略）" prop="status">
        <el-radio-group v-model="formData.status">
          <el-radio label="1">请选择字典生成</el-radio>
        </el-radio-group>
      </el-form-item>
    </el-form>
    <template #footer>
      <el-button @click="submitForm" type="primary" :disabled="formLoading">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script setup lang="ts">
import { ScheduleSuggestApi, ScheduleSuggestVO } from '@/api/ai/schedulesuggest'

/** 大模型调度建议 表单 */
defineOptions({ name: 'ScheduleSuggestForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  modelId: undefined,
  conversationId: undefined,
  messageId: undefined,
  content: undefined,
  status: undefined,
})
const formRules = reactive({
  modelId: [{ required: true, message: '模型id不能为空', trigger: 'blur' }],
  conversationId: [{ required: true, message: '会话id不能为空', trigger: 'blur' }],
  messageId: [{ required: true, message: '消息id不能为空', trigger: 'blur' }],
  status: [{ required: true, message: '状态（0-未处理 1-已采纳 2-已忽略）不能为空', trigger: 'blur' }],
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await ScheduleSuggestApi.getScheduleSuggest(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as ScheduleSuggestVO
    if (formType.value === 'create') {
      await ScheduleSuggestApi.createScheduleSuggest(data)
      message.success(t('common.createSuccess'))
    } else {
      await ScheduleSuggestApi.updateScheduleSuggest(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    modelId: undefined,
    conversationId: undefined,
    messageId: undefined,
    content: undefined,
    status: undefined,
  }
  formRef.value?.resetFields()
}
</script>